/***************************************************************************
                          tabgrip.h  -  description
                             -------------------
    begin                : Fri Sep 13 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABGRIP_H
#define TABGRIP_H

#include <tqwidget.h>

/**
  *@author Troy Corbin Jr.
  */

class TabGrip : public TQWidget
{
   TQ_OBJECT
  
	public:
								TabGrip(TQWidget *parent=0, const char *name=0);
								~TabGrip();
		void				paintEvent( TQPaintEvent* );
		void				mouseMoveEvent( TQMouseEvent *event );
		void				mousePressEvent( TQMouseEvent *event );
		void				mouseReleaseEvent( TQMouseEvent *event );

	signals:
		void				wasDragged( const TQPoint&, const TQPoint& );

	private:
		bool				isDragging;
		bool				couldDrag;
		TQPoint			offset;
};

#endif
